from setuptools import setup, find_packages

import codecs
import os


# Setting up
setup(
    name="arturotest",
    version='0.0.3-beta.1',
    author="rtvro",
    author_email="<example@gmail.com>",
    description='test package',
    install_requires=[],
    long_description_content_type="text/markdown",
    long_description='test package long'
)

